@@ -19,10 +19,10 @@ import java.io.IOException;
 import java.io.PrintWriter;
 import java.util.ResourceBundle;
 
-import javax.servlet.ServletException;
-import javax.servlet.http.HttpServlet;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.http.HttpServlet;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
 
 import util.HTMLFilter;
 
@@ -94,7 +94,7 @@ public class RequestInfoExample extends HttpServlet {
         out.println("</td></tr>");
 
         String cipherSuite=
-                (String)request.getAttribute("javax.servlet.request.cipher_suite");
+                (String)request.getAttribute("jakarta.servlet.request.cipher_suite");
         if(cipherSuite!=null){
             out.println("<tr><td>");
             out.println("SSLCipherSuite:");
